/* Kod för övningar och egna test. */
// --------------------------------------------------
// Globala variabler och konstanter
const nrOfPuzzles = 6;  // Antal pussel i img-mappen
let puzzleNr;           // Aktuellt pussel
let pieceElems;         // Array med element för pusselbitar
let boxElems;           // Array med element för rutor i pusslet
let msgElem;            // Element för meddelande
// --------------------------------------------------
// Initiering av globala variabler och händelser.
function init() {
    pieceElems = document.querySelectorAll("#pieces img");
    boxElems = document.querySelectorAll("#puzzle img");
    for (let i = 0; i < 4; i++) {
        pieceElems[i].addEventListener("click", clickPiece);
        boxElems[i].addEventListener("click", clickBox);
    }
    msgElem = document.querySelector("#message");
    document.querySelector("#newPuzzleBtn").addEventListener("click", newPuzzle);
} // Slut init
window.addEventListener("load", init);
// --------------------------------------------------
// Välj slumpmässigt ett pussel och lägg ut pusselbitarna i den övre raden.
// Ta också bort bilderna i föregående pussel.
function newPuzzle() {
    puzzleNr = Math.floor(6 * Math.random()) + 1;
    let imgNrs = [1, 2, 3, 4];
    for (let i = 0; i < pieceElems.length; i++) {
        let r = Math.floor(imgNrs.length * Math.random());
        pieceElems[i].src = "img/puzzles/" + puzzleNr + "/" + imgNrs[r] + ".jpg";
        imgNrs.splice(r, 1); // Ta bort valt nummer, så att det inte kan väljas igen
    }
    for (let i = 0; i < boxElems.length; i++) {
        boxElems[i].src = "img/puzzles/empty.png";
    }
    msgElem.innerText = "";
} // Slut newPuzzle
// --------------------------------------------------
// Markera den pusselbit som användaren klickade på.
function clickPiece() {
    if (this.src.endsWith("empty.png")) { // Rutan är tom
        return;
    }
    for (let i = 0; i < pieceElems.length; i++) { // Ta först bort markeringar på alla
        pieceElems[i].classList.remove("selected");
    }
    this.classList.add("selected"); // Markera sedan den som klickades
} // Slut clickPiece
// --------------------------------------------------
// Om det redan finns en pusselbit i rutan, läggs den tillbaks i den övre raden.
// Sedan, om det finns en vald pusselbit, flyttas den till rutan.
function clickBox() {
   if (!this.src.endsWith("empty.png")) { // Rutan är ej tom
        for (let i = 0; i < pieceElems.length; i++) {       // Leta efter ...
            if (pieceElems[i].src.endsWith("empty.png")) {  // ... tom plats ...
                pieceElems[i].src = this.src;   // ... och lägg tillbaks pusselbiten
                this.src = "img/puzzles/empty.png";
                break;
            }
        }
    }
    selectedPiece = document.querySelector("#pieces .selected");
    if (selectedPiece) { // Det finns en vald pusselbit
        this.src = selectedPiece.src;
        selectedPiece.src = "img/puzzles/empty.png";
        selectedPiece.classList.remove("selected");
        checkPuzzle(); // Kontrollera om pusslet är klart
    }
} // Slut clickBox
// --------------------------------------------------
// Kontrollerar alla rutor i pusslet. Ligger bilderna i nummerordning, är pusslet klart.
function checkPuzzle() {
    for (let i = 0; i < boxElems.length; i++) {
        let url = boxElems[i].src;
        let nr = url.substring(url.lastIndexOf("/")+1, url.lastIndexOf("."));
        if (nr != i + 1) { // Bilden på fel plats
            return;
        }
    }
    msgElem.innerText = "Grattis, pusslet är klart.";
} // Slut checkPuzzle
// --------------------------------------------------
